<?php

namespace AsyncAws\Sns\Exception;

use AsyncAws\Core\Exception\Http\ClientException;

/**
 * Indicates that a parameter in the request is invalid.
 */
final class ValidationException extends ClientException
{
}
