<?php

namespace AsyncAws\Sns\Exception;

use AsyncAws\Core\Exception\Http\ServerException;

/**
 * Indicates an internal service error.
 */
final class InternalErrorException extends ServerException
{
}
